mchammer
========

.. automodule:: mchammer

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :toctree:
      :template: class.rst
      :nosignatures:
   
      Atom
      Bond
      Collapser
      MCStepResult
      Molecule
      Optimizer
      Result
      StepResult
   
   


   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree:
      :nosignatures:
   
      get_atom_distance
      get_bond_vector
      get_radius
      rotate_molecule_by_angle
      rotation_matrix_arbitrary_axis
      test_move
      translate_atoms_along_vector
      translate_molecule_along_vector
   
   

   
   
   



